@@ -7,34 +7,35 @@ from contextlib import contextmanager
 from email.mime.multipart import MIMEMultipart
 from email.mime.text import MIMEText
 
-from pab.config import APP_CONFIG
+from pab.config import Config
 
+APP_CONFIG = None
 
 logger = logging.getLogger("pab.alert")
 SSL_CONTEXT = ssl.create_default_context()
 
 
 @contextmanager
-def smtp():
-    with smtplib.SMTP(APP_CONFIG.get("emails.host"), port=APP_CONFIG.get("emails.port")) as _server:
+def smtp(config: Config):
+    with smtplib.SMTP(config.get("emails.host"), port=config.get("emails.port")) as _server:
         _server.starttls(context=SSL_CONTEXT)
-        _server.login(APP_CONFIG.get("emails.address"), APP_CONFIG.get("emails.password"))
+        _server.login(config.get("emails.user"), config.get("emails.password"))
         yield _server
 
 
-def alert_exception(exception):
+def alert_exception(exception, config: Config):
     content = "Error on PyAutoBlockchain:\n\n"
     content += ''.join(traceback.format_tb(exception.__traceback__))
     content += f"\n{type(exception).__name__}: {exception}"
-    send_email(content)
+    send_email(content, config)
 
 
-def send_email(content):
-    if APP_CONFIG.get("emails.enabled"):
-        with smtp() as _server:
+def send_email(content, config: Config):
+    if config.get("emails.enabled"):
+        with smtp(config) as _server:
             msg = MIMEMultipart()
-            msg['From'] = APP_CONFIG.get("emails.address")
-            msg['To'] = APP_CONFIG.get("emails.recipient")
+            msg['From'] = config.get("emails.user")
+            msg['To'] = config.get("emails.recipient")
             msg['Subject'] = "Error on PyAutoBlockchain"
             msg.attach(MIMEText(content, 'plain'))
             _server.send_message(msg)
