@@ -6,19 +6,18 @@ import os
 import sys
 import getpass
 import logging
-import subprocess
 
 from pathlib import Path
 from contextlib import contextmanager
 from argparse import ArgumentParser, RawDescriptionHelpFormatter
 
-from pab.blockchain import Blockchain
 from pab.core import PAB
-from pab.config import APP_CONFIG, DATETIME_FORMAT, CONFIG_FILE, KEY_FILE, override_config_with_defaults, valid_config_found
-from pab.strategy import import_local_strategies
-from pab.utils import create_keyfile, KeyfileOverrideException, print_strats, json_strats
+from pab.config import DATETIME_FORMAT, Config
+from pab.strategy import import_strategies
+from pab.utils import print_strats, json_strats
 from pab.alert import alert_exception
-from pab.queue import QueueLoader
+from pab.init import initialize_project as _initialize_project
+from pab.accounts import create_keyfile, KeyfileOverrideException
 
 
 def _create_logger():
@@ -51,15 +50,8 @@ def _create_keyfile(args, logger):
     logger.info(f"Keyfile written to '{out}'")
 
 
-def edit_config(args, logger):
-    if not valid_config_found():
-        override_config_with_defaults()
-    editor = os.environ.get("EDITOR", "vim")
-    subprocess.call([editor, CONFIG_FILE])
-
-
 def list_strats(args, logger):
-    import_local_strategies()
+    import_strategies(Path.cwd())
     if args.json:
         json.dump(json_strats(), sys.stdout)
         print()
@@ -67,12 +59,20 @@ def list_strats(args, logger):
         print_strats(args.verbose)
 
 
+def initialize_project(args, logger):
+    directory = args.directory
+    if directory is None:
+        directory = Path.cwd()
+    _initialize_project(directory)
+
+
 def run(args, logger):
-    blockchain = Blockchain(APP_CONFIG.get('endpoint'), int(APP_CONFIG.get("chainId")), APP_CONFIG.get("blockchain"))
-    blockchain.load_wallet(APP_CONFIG.get('myAddress'), args.keyfile)
-    queue = QueueLoader(blockchain).load()
-    pounder = PAB(queue)
-    pounder.start()
+    envs = filter(lambda e: e != '', [env.strip() for env in args.envs.split(',')])
+    keyfiles = filter(lambda kf: kf != '', [kf.strip() for kf in args.keyfiles.split(',')])
+    keyfiles_paths = [Path(kf) for kf in keyfiles]
+    pab = PAB(Path.cwd(), keyfiles_paths, envs)
+    sys.excepthook = exception_handler(logger, pab.config)
+    pab.start()
 
 
 def parser():
@@ -85,15 +85,17 @@ def parser():
     p_create.set_defaults(func=list_strats)
 
     p_run = subparsers.add_parser("run", help="Run tasks")
-    p_run.add_argument("-k", "--keyfile", action="store", help="Wallet Encrypted Private Key. If not used will load from resources/key.file as default.", default=None)
+    p_run.add_argument("-k", "--keyfiles", action="store", help="List of keyfiles separated by commas.", default='')
+    p_run.add_argument("-e", "--envs", help="List of environments separated by commas.", default="")
     p_run.set_defaults(func=run)
 
     p_createkf = subparsers.add_parser("create-keyfile", help="Create keyfile. You'll need your private key and a new password for the keyfile.")
-    p_createkf.add_argument("-o", "--output", action="store", help="Output location for keyfile.", default=str(KEY_FILE))
+    p_createkf.add_argument("-o", "--output", action="store", help="Output location for keyfile.", default="key.file")
     p_createkf.set_defaults(func=_create_keyfile)
 
-    p_edit = subparsers.add_parser("edit-config", help="Create or edit config file.")
-    p_edit.set_defaults(func=edit_config)
+    p_init = subparsers.add_parser("init", help="Initialize PAB project in current directory.")
+    p_init.add_argument("-d", "--directory", action="store", help="Initialize project in diferent directory.", default=None)
+    p_init.set_defaults(func=initialize_project)
     return p
 
 
@@ -109,20 +111,19 @@ def _catch_ctrlc():
             os._exit(1)
 
 
-def exception_handler(logger):
+def exception_handler(logger, config: Config):
     def _handle_exceptions(exc_type, exc_value, exc_traceback):
         if issubclass(exc_type, KeyboardInterrupt):
             sys.__excepthook__(exc_type, exc_value, exc_traceback)
             return
         logger.critical("Uncaught exception", exc_info=(exc_type, exc_value, exc_traceback))
-        alert_exception(exc_value)
+        alert_exception(exc_value, config)
     return _handle_exceptions
 
 
-def main():
+def main(args):
     logger = _create_logger()
-    args = parser().parse_args()
-    sys.excepthook = exception_handler(logger)
+    args = parser().parse_args(args)
     if hasattr(args, 'func'):
         with _catch_ctrlc():
             args.func(args, logger)
@@ -130,5 +131,9 @@ def main():
         parser().print_help()
 
 
+def ep():
+    main(sys.argv[1:])
+
+
 if __name__ == "__main__":
-    main()
+    ep()
\ No newline at end of file
